## [0.1.1] - 2026-03-01

### Summary

refactor(docs): configuration management system

### Core

- update src/vallm/__init__.py
- update src/vallm/__main__.py
- update src/vallm/config.py
- update src/vallm/core/__init__.py
- update src/vallm/core/ast_compare.py
- update src/vallm/core/graph_builder.py
- update src/vallm/core/proposal.py
- update src/vallm/hookspecs.py

### Docs

- docs: update TODO.md

### Test

- update tests/test_vallm.py

### Build

- update pyproject.toml

### Config

- config: update goal.yaml

### Other

- update .gitignore
- build: update Makefile
- update TICKET


# CHANGELOG

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- Initial project setup

### Changed

### Fixed

### Removed

---

Last updated: 2026-03-01